//      __       __
/*   __/ /_______\ \__     ___ ___ __ _                       _ __ ___ ___
 *__/ / /  .---.  \ \ \___/                                               \___
 *_/ | '  /  / /\  ` | \_/          (C) Copyright 2001, Chris Page         \__
 * \ | |  | / / |  | | / \  Released under the GNU General Public License  /
 *  >| .  \/ /  /  . |<   >--- --- -- -                       - -- --- ---<
 * / \_ \  `/__'  / _/ \ /  This program is free software released under   \
 * \ \__ \_______/ __/ / \   the GNU GPL. Please see the COPYING file in   /
 *  \  \_         _/  /   \   the distribution archive for more details   /
 * //\ \__  ___  __/ /\\ //\                                             /
 *- --\  /_/   \_\  /-- - --\                                           /-----
 *-----\_/       \_/---------\   ___________________________________   /------
 *                            \_/                                   \_/
 *
 * Note to non-developer type persons: this is the source code for texgen, if
 * you're looking for documentation on how to use the program look at the
 * readme.wri file!
 *
 * \author Chris Page 
 * \file htmlsupport.c
 * HTML file generation functions.
 * This file contains a couple of functions which create the frameset and notes
 * documents in the texture family directory. This is fairly wasteful, as I could 
 * just include them in the distribution archive and ask the user to copy them 
 * over. But this way there is less work for the user to do and less to go wrong.. 
 *
 * Contact: Chris <chris@starforge.co.uk> 
 * Updates: http://starforge.co.uk/t2/files/texgen.zip
 *
 * This program is free software released under the GNU General Public
 * License. You may redistribute and/or modify this program under the terms
 * of that license as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * To get a copy of the GNU General Puplic License, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include"stdio.h"
#include"htmlsupport.h"

static const char *frameset = \
"<HTML>\n<HEAD>\n<TITLE>Texture Families Index</TITLE>\n" \
"<link rel=\"stylesheet\" type=\"text/css\" href=\"family.css\" />\n" \
"</HEAD>\n\n" \
"<frameset cols=\"160,*\" frameborder=\"0\">\n" \
"<frame frameborder=\"0\" scrolling=\"auto\" marginheight=\"0\" marginwidth=\"0\" src=\"families.html\" name=\"menu\">\n" \
"<frame frameborder=\"0\" scrolling=\"auto\" marginheight=\"0\" marginwidth=\"0\" src=\"notes.html\" name=\"body\">\n" \
"</frameset>\n</HTML>\n";

static const char *notes = \
"<HTML>\n<HEAD>\n<TITLE>Notes</TITLE>" \
"<link rel=\"stylesheet\" type=\"text/css\" href=\"family.css\" />\n" \
"</HEAD><BODY>\n" \
"<P class=\"title\">Texture Family Index</P>\n" \
"<P class=\"smallcenter\">HTML generated by TexGen</P>\n" \
"<P>Please select a family from the index on the left. Once a family is selected, move the mouse over\n" \
"a texture to display its name in the status bar at the bottom of your browser window (note: some\n" \
"browsers may also display the name in a popup if you leave the mouse over an image for a period\n" \
"of time)</P>\n" \
"<P class=\"smallcenter\">If you have any comments, questions or problems concerning texgen email the author at <A HREF=\"mailto:chris@starforge.co.uk\">chris@starforge.co.uk</A></P>\n"\
"</BODY></HEAD>";

//! Write the top level frameset
/*! This creates the index.html file the user loads into a web browser. The list of families
 *  is shown in a fram eon the left while the texture images are shown on the right.
 */
void writeframeset(void)
{
    FILE *frame;

    if((frame = fopen("index.html", "w")) == NULL) {
        printf("ERROR: Could not write frameset!\n");
    } else {
        fwrite(frameset, strlen(frameset), 1, frame);
        fclose(frame);
    }

    return;
}

//! Write the pointless notes page
/*! This generates a (rather useless) notes page which is shown in the firght frame until
 *  the user selects a family to view
 */
void writenotes(void)
{    
    FILE *note;

    if((note = fopen("notes.html", "w")) == NULL) {
        printf("ERROR: Could not write notes!\n");
    } else {
        fwrite(notes, strlen(notes), 1, note);
        fclose(note);
    }

    return;
}
